@@ -12,7 +12,11 @@
     f.close()
     
 """
-from ftplib import FTP, FTP_TLS
+from ftplib import FTP
+try:
+    from ftplib import FTP_TLS
+except ImportError:
+    FTP_TLS = None
 import os
 import cStringIO
 import re
@@ -23,14 +27,14 @@ class ftpretty(object):
     """ A wrapper for FTP connections """
     conn = None
     tmp_output = None
-    relative_paths = {'.', '..'}
+    relative_paths = set(['.', '..'])
 
     def __init__(self, host, user, password, 
         secure=False, passive=True, ftp_conn=None, **kwargs):
 
         if ftp_conn:
             self.conn = ftp_conn
-        elif secure:
+        elif secure and FTP_TLS:
             self.conn = FTP_TLS(host=host, user=user, passwd=password, **kwargs)
             self.conn.prot_p()
         else:
